summaryrefslogtreecommitdiff
path: root/gdb/ui-out.h
diff options
context:
space:
mode:
authorAndrew Cagney <cagney@redhat.com>2001-05-12 04:08:24 +0000
committerAndrew Cagney <cagney@redhat.com>2001-05-12 04:08:24 +0000
commitb6953506f4d41d46e87650188520283158c37a51 (patch)
tree6a490304d73322cd9614894786fc6910b285658b /gdb/ui-out.h
parent7f967294c9f2631027b4c1081c8fb12072da6ba8 (diff)
downloadgdb-b6953506f4d41d46e87650188520283158c37a51.tar.gz
s/ui_out_list/ui_out_tupple/
Diffstat (limited to 'gdb/ui-out.h')
-rw-r--r--gdb/ui-out.h17
1 files changed, 12 insertions, 5 deletions
diff --git a/gdb/ui-out.h b/gdb/ui-out.h
index ed2a289f0b5..9fe0be7ae7e 100644
--- a/gdb/ui-out.h
+++ b/gdb/ui-out.h
@@ -66,11 +66,11 @@ struct ui_stream
/* Prototypes for ui-out API. */
/* A result is a recursive data structure consisting of lists and
- tupples. */
+ tuples. */
enum ui_out_type
{
- ui_out_type_tupple,
+ ui_out_type_tuple,
ui_out_type_list
};
@@ -84,7 +84,7 @@ extern struct cleanup *ui_out_begin_cleanup_end (struct ui_out *uiout,
enum ui_out_type level_type,
const char *id);
/* A table can be considered a special tupple/list combination with
the implied structure: ``table = { hdr = { header, ... } , body = [ {
field, ... }, ... ] }'' */
@@ -101,11 +101,18 @@ extern void ui_out_table_end (struct ui_out *uiout);
/* Compatibility wrappers, new code should use ui_out_begin() and
ui_out_end(). */
-extern void ui_out_list_begin (struct ui_out *uiout, char *lstid);
+extern void ui_out_list_begin (struct ui_out *uiout);
extern void ui_out_list_end (struct ui_out *uiout);
-extern struct cleanup *make_cleanup_ui_out_list_end (struct ui_out *uiout);
+extern struct cleanup *make_cleanup_ui_out_list_begin_end (struct ui_out *uiout);
+
+extern void ui_out_tuple_begin (struct ui_out *uiout, const char *id);
+
+extern void ui_out_tuple_end (struct ui_out *uiout);
+
+extern struct cleanup *make_cleanup_ui_out_tuple_begin_end (struct ui_out *uiout,
+ const char *id);
extern void ui_out_field_int (struct ui_out *uiout, char *fldname, int value);
@@ -84,7 +84,7 @@ extern struct cleanup *ui_out_begin_cleanup_end (struct ui_out *uiout,
enum ui_out_type level_type,
const char *id);
-/* A table can be considered a special tupple/list combination with
+/* A table can be considered a special tuple/list combination with
the implied structure: ``table = { hdr = { header, ... } , body = [ {
field, ... }, ... ] }'' */